
# Analysis from: Testosterone-mediated behavior shapes the emergent properties of social networks
# Roslyn Dakin, Ignacio T. Moore, Brent M. Horton, Ben J. Vernasco, and T. Brandt Ryder
# Revised December 2019

library(dplyr)
library(data.table)

# Get the observed social interaction data:
year3 <- read.csv('filtered_interactions_nodups_times_durations_052418.csv', stringsAsFactors=F)[,c('date','nTime','Color1','Color2','Lek','studyyear','DL','sitefix')]; dim(year3)
year12 <- read.csv('filtered_interactions_nodups_times_durations_011018.csv', stringsAsFactors=F)[,c('date','nTime','Color1','Color2','Lek','studyyear','DL','sitefix')]; dim(year12)
ally <- rbind(year12, year3); head(ally); dim(ally) # Now, we duplicate and reverse individual 1 & individual 2 to account for all interactions:
allyX <- ally
allyX$Color1 <- ally$Color2; allyX$Color2 <- ally$Color1
dim(ally); dim(allyX)
ally <- rbind(ally, allyX)
ally$Color1[ally$Color1=='OX-'] <- 'OX'
ally$Color2[ally$Color2=='OX-'] <- 'OX' 
ally$sitefix[ally$sitefix=='OX-'] <- 'OX'
all(levels(factor(ally$Color1))==levels(factor(ally$Color2))); dim(ally) # 73,770

leklookup <- unique(ally[,c('Lek','sitefix','studyyear')]); rownames(leklookup) <- 1:nrow(leklookup); head(leklookup)

rel.files <- list.files()[grep('allint_perm', list.files())]; rel.files
myfiles <- vector('list', length=length(rel.files))
for(j in 1:length(rel.files)){
	allyP <-  read.csv(rel.files[j], stringsAsFactors=F)
	allyP$Lek <- NA; allyP$sitefix <- allyP$site
	allyP$sitefix[allyP$sitefix %in% c('GXWA','GXWB')] <- 'GXW'
	for(i in 1:nrow(allyP)){
		yr <- allyP$studyyear[i]
		site <- allyP$sitefix[i]
		temp <- subset(leklookup, studyyear==yr & sitefix==site)
		if(nrow(temp) > 0){
			allyP$Lek[i] <- temp$Lek
		}
		print(i)
	}
	
	allyP2 <- allyP; allyP2$Color1 <- allyP$Color2; allyP2$Color2 <- allyP$Color1
	
	allyP$dyadC <- paste(allyP$Color1, allyP$Color2)
	allyP2$dyadC <- paste(allyP2$Color1, allyP2$Color2)
	allyP <- rbind(allyP, allyP2)
	
	allyP$dyadC <- paste(allyP$Color1, allyP$Color2, sep='_')
	
	allyPS <- summarize(group_by(allyP, studyyear, Lek, DL, dyadC), freq=n())
	allyPS$ID <- paste(allyPS$studyyear, allyPS$Lek, allyPS$DL, allyPS$dyadC)
	
	myfiles[[j]] <- allyPS
}

allpermdyads <- (unique(unlist(simplify2array(lapply(myfiles, '[', 'ID')))))
head(allpermdyads); length(allpermdyads) # 14196
allpermdyads <- data.frame(dyadC=allpermdyads, avg.freq=NA, stringsAsFactors=F); head(allpermdyads); dim(allpermdyads)

for(j in 1:nrow(allpermdyads)){
	temp <- rep(NA, 100)
	dyad <- allpermdyads$dyadC[j]
	for(i in 1:100){
		x <- unlist(myfiles[[i]][myfiles[[i]][,'ID']==dyad,'freq'])
		if(any(x)){
			temp[i] <- x
		} else {
			temp[i] <- 0
		}
	}
	allpermdyads$avg.freq[j] <- mean(temp)
	print(j)
}

# write.csv(allpermdyads, file='allpermdyads.csv', row.names=F)
allpermdyads <- read.csv(file='allpermdyads.csv', stringsAsFactors=F); dim(allpermdyads)

head(ally); dim(ally)
ally$ID <- paste(ally$studyyear, ally$Lek, ally$DL, paste(ally$Color1, ally$Color2, sep='_'))

ally$compare_perm <- NA

for(i in 1:73770){
	check <-  subset(allpermdyads, dyadC==ally$ID[i])$avg.freq
	if(!any(check)){
		check <- 0
	}
	ally$compare_perm[i] <- nrow(subset(ally, ID==ally$ID[i])) > check
	print(i)
}

head(ally); tail(ally); table(ally$compare_perm) # save the observed interactions with permutation result
# write.csv(ally, file='ally_with_pre-net_perm.csv', row.names=F)

# How many unique partnerships per permutation run?
perm.results <- data.frame(n.partnerships=rep(NA, 100), n.interactions=rep(NA, 100))
for(i in 1:100){
	perm.results$n.partnerships[[i]] <- length(unique(myfiles[[i]]$ID))/2
	perm.results$n.interactions[[i]] <-sum(myfiles[[i]]$freq)/2
}
hist(perm.results$n.partnerships)
hist(perm.results$n.interactions)
t.test(perm.results$n.partnerships); length(unique(ally$ID))/2
t.test(perm.results$n.interactions); nrow(ally)/2


# Check consistency of the permutation results, to validate 100 iterations:

rep.list <- vector('list', length=nrow(allpermdyads))
rep.ids <- 1:nrow(allpermdyads)
for(j in 1:length(rep.list)){
	temp <- rep(NA, 100)
	dyad <- allpermdyads$dyadC[rep.ids[j]]
	for(i in 1:length(temp)){
		x <- unlist(myfiles[[i]][myfiles[[i]][,'ID']==dyad,'freq'])
		if(any(x)){
			temp[i] <- x
		} else {
			temp[i] <- 0
		}
	}
	rep.list[[j]] <- data.frame(ID=rep(allpermdyads$dyadC[j], 100), freq=temp, stringsAsFactors=F)
	print(j)
}
rep.listX <- data.table::rbindlist(rep.list)


cor.data <- rep(NA, 100) # To store 100 correlations

# First approach: examine just the 2996 session-partnerships that actually occurred
pdat <- data.frame(ID=unique(ally$ID), occur1=NA, occur2=NA)
for(k in 1:100){
	pdat <- data.frame(ID=unique(ally$ID), occur1=NA, occur2=NA)
	ks <- sample(1:99, 1, replace=F)
	temp <- subset(rep.listX, ID %in% pdat$ID)
	pdat$occur1[1:5974] <- temp$freq[seq(0, nrow(temp)-1, by=100)+ks]
	pdat$occur1[5975:nrow(pdat)] <- 0

	pdat$occur2[1:5974] <- temp$freq[seq(0, nrow(temp)-1, by=100)+ks+1]
	pdat$occur2[5875:nrow(pdat)] <- 0
	
	pdat <- pdat[with(pdat, order(occur1, occur2)),]
	
	cor.data[k] <- cor.test(pdat$occur1[seq(1,5996,by=2)], pdat$occur2[seq(1,5996,by=2)])$est
}; t.test(cor.data) # r = 0.60, 95% CI 0.60-0.61

for(k in 1:100){
	pdat <- data.frame(ID=unique(ally$ID), occur1=NA, occur2=NA)
	ks <- sample(1:99, 1, replace=F)
	temp <- subset(rep.listX, ID %in% pdat$ID)
	pdat$occur1[1:5974] <- temp$freq[seq(0, nrow(temp)-1, by=100)+ks]
	pdat$occur1[5975:nrow(pdat)] <- 0

	t2 <- summarize(group_by(temp, ID), freq=mean(freq))
	pdat$occur2[1:5974] <- t2$freq[match(temp$ID[seq(0, nrow(temp)-1, by=100)+ks], t2$ID)]
	
	pdat$occur2[5875:nrow(pdat)] <- 0
	
	pdat <- pdat[with(pdat, order(occur1, occur2)),]
	
	cor.data[k] <- cor.test(pdat$occur1[seq(1,5996,by=2)], pdat$occur2[seq(1,5996,by=2)])$est
}; t.test(cor.data) # r = 0.78, 95% CI 0.78-0.78


# Second approach: examine session-partnerships that occurred in any permutation
for(k in 1:100){	
	# index <- seq(0, 1419599, by=100) + k
	ks <- sample(1:99, 1, replace=F)
	index1 <- seq(0, 1419599, by=100) + ks[1]
	index2 <- seq(0, 1419599, by=100) + ks[1] + 1
	# cor.data[k] <- cor.test(rep.listX$freq[index], allpermdyads$avg.freq)$est
	cor.data[k] <- cor.test(rep.listX$freq[index1], rep.listX$freq[index2])$est
	print(k)
}
hist(cor.data); mean(cor.data)

# r = 0.78.9 [78.8 to 79.1]. SD 0.007. comparing the average to any one measurement.
# r = 0.62 [0.62, 0.62], SD 0.01. comparing two randomly-selected permutations. 




