
library(lme4)
library(lmerTest)

myfun <- function(mod2){
	tab <- summary(mod2)$coef
	est <- tab['meanT_TH','Estimate']
	lwr <- tab['meanT_TH','Estimate'] + 1.96*tab['meanT_TH','Std. Error']
	upr <- tab['meanT_TH','Estimate'] - 1.96*tab['meanT_TH','Std. Error']
	return(c(est, lwr, upr))
}

# Repeat analysis with alternative raw data processing, adjusting the spatial parameters for a social interaction:

net.prop_6 <- read.csv('network_properties_delta_6.csv', stringsAsFactors=F)
net.prop_7 <- read.csv('network_properties_delta_7.csv', stringsAsFactors=F)
net.prop_8 <- read.csv('network_properties_delta_8.csv', stringsAsFactors=F)
net.prop_9 <- read.csv('network_properties_delta_9.csv', stringsAsFactors=F)
net.prop_10 <- read.csv('network_properties_delta_10.csv', stringsAsFactors=F)
net.prop_11 <- read.csv('network_properties_delta_11.csv', stringsAsFactors=F)
net.prop_12 <- read.csv('network_properties_delta_12.csv', stringsAsFactors=F)

results <- data.frame(delta=6:12, est=NA, lwr=NA, upr=NA)

# Fit and compare candidate models:

# Social specialization
summary(mod2 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_6, Tplus==0))))
results[1,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_7, Tplus==0))))
results[2,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_8, Tplus==0))))
results[3,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_9, Tplus==0))))
results[4,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_10, Tplus==0))))
results[5,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_11, Tplus==0))))
results[6,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_12, Tplus==0))))
results[7,2:4] <- myfun(mod2)

dev.new(width=6, height=2)
par(mfrow=c(1,3), las=1, mar=c(4,4,2,0.5), mgp=c(2,0.5,0), tck=-0.05, bty='l')
plot(results$est, pch=16, ylim=c(-0.8, 0.8), ylab='Coef (+/- 95% CI)', xlab='Threshold', xaxt='n', main='Specialization'); abline(h=0, lty=3)
axis(1, at=1:7, labels=results$delta)
segments(x0=1:7, y0=results$lwr, y1=results$upr)

# Stability
summary(mod2 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_6, Tplus==0))))
results[1,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_7, Tplus==0))))
results[2,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_8, Tplus==0))))
results[3,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_9, Tplus==0))))
results[4,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_10, Tplus==0))))
results[5,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_11, Tplus==0))))
results[6,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop_12, Tplus==0))))
results[7,2:4] <- myfun(mod2)

plot(results$est, pch=16, ylim=c(-0.8, 0.8), ylab='Coef (+/- 95% CI)', xlab='Threshold', xaxt='n', main='Stability'); abline(h=0, lty=3)
axis(1, at=1:7, labels=results$delta)
segments(x0=1:7, y0=results$lwr, y1=results$upr)

# Behavioral assortment
summary(mod1 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop_6, Tplus==0))))
results[1,2:4] <- myfun(mod2)
summary(mod1 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop_7, Tplus==0))))
results[2,2:4] <- myfun(mod2)
summary(mod1 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop_8, Tplus==0))))
results[3,2:4] <- myfun(mod2)
summary(mod1 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop_9, Tplus==0))))
results[4,2:4] <- myfun(mod2)
summary(mod1 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop_10, Tplus==0))))
results[5,2:4] <- myfun(mod2)
summary(mod1 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop_11, Tplus==0))))
results[6,2:4] <- myfun(mod2)
summary(mod1 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop_12, Tplus==0))))
results[7,2:4] <- myfun(mod2)

plot(results$est, pch=16, ylim=c(-0.8, 0.8), ylab='Coef (+/- 95% CI)', xlab='Threshold', xaxt='n', main='Assortment'); abline(h=0, lty=3)
axis(1, at=1:7, labels=results$delta)
segments(x0=1:7, y0=results$lwr, y1=results$upr)







# Correlations among the metrics:

(cor.vals <- data.frame(spec=rep(NA, 7), stab=NA, assort=NA))

dev.new(width=7, height=3)
par(mfrow=c(3,6), las=1, mar=c(1,3,0.5,0.5), mgp=c(2,0.5,0), tck=-0.05, bty='l')
dat <- data.frame(cbind(net.prop_6$specialization,net.prop_7$specialization,net.prop_8$specialization,net.prop_9$specialization,net.prop_10$specialization,net.prop_11$specialization,net.prop_12$specialization))
names(dat) <- paste('Delta',6:12, sep=' ')
for(i in c(1,2,3,4,6,7)){
	plot(dat[,i] ~ dat[,5], pch=16, cex=0.6, col=rgb(0,0,0,0.3), asp=1, xlab='', ylab=names(dat)[i]);abline(a=0, b=1, col='red')
}
for(i in c(1,2,3,4,6,7)){
	cor.vals$spec[i] <- unname(cor.test(dat[,i], dat[,5])$est)
}

dat <- data.frame(cbind(net.prop_6$stability2,net.prop_7$stability2,net.prop_8$stability2,net.prop_9$stability2,net.prop_10$stability2,net.prop_11$stability2,net.prop_12$stability2))
names(dat) <- paste('Delta',6:12, sep=' ')
for(i in c(1,2,3,4,6,7)){
	plot(dat[,i] ~ dat[,5], pch=16, cex=0.6, col=rgb(0,0,0,0.3), asp=1, xlab='', ylab=names(dat)[i]);abline(a=0, b=1, col='red')
}
for(i in c(1,2,3,4,6,7)){
	cor.vals$stab[i] <- unname(cor.test(dat[,i], dat[,5])$est)
}

dat <- data.frame(cbind(net.prop_6$behavASSORT,net.prop_7$behavASSORT,net.prop_8$behavASSORT,net.prop_9$behavASSORT,net.prop_10$behavASSORT,net.prop_11$behavASSORT,net.prop_12$behavASSORT))
names(dat) <- paste('Delta',6:12, sep=' ')
for(i in c(1,2,3,4,6,7)){
	plot(dat[,i] ~ dat[,5], pch=16, cex=0.6, col=rgb(0,0,0,0.3), asp=1, xlab='', ylab=names(dat)[i]);abline(a=0, b=1, col='red')
}
for(i in c(1,2,3,4,6,7)){
	cor.vals$assort[i] <- unname(cor.test(dat[,i], dat[,5])$est)
}





# Alternate stability thresholds:

net.prop <- read.csv('network_properties_additional_stability_thresholds.csv', stringsAsFactors=F)

results <- data.frame(thresh=9:3, est=NA, lwr=NA, upr=NA)

# Stability
summary(mod2 <- (lmer(stability2_thresh9 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0))))
results[1,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2_thresh8 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0))))
results[2,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2_thresh7 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0))))
results[3,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2_thresh6 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0))))
results[4,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2_thresh5 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0))))
results[5,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2_thresh4 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0))))
results[6,2:4] <- myfun(mod2)
summary(mod2 <- (lmer(stability2_thresh3 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0))))
results[7,2:4] <- myfun(mod2)

dev.new(width=6, height=2)
par(mfrow=c(1,3), las=1, mar=c(4,4,2,0.5), mgp=c(2,0.5,0), tck=-0.05, bty='l')
plot(results$est, pch=16, ylim=c(-0.8, 0.8), ylab='Coef (+/- 95% CI)', xlab='Threshold', xaxt='n', main='Stability'); abline(h=0, lty=3)
axis(1, at=1:7, labels=results$thresh)
segments(x0=1:7, y0=results$lwr, y1=results$upr)

(cor.vals <- data.frame(stab=rep(NA, 30)))

dev.new(width=7, height=3)
par(mfrow=c(3,6), las=1, mar=c(1,3,0.5,0.5), mgp=c(2,0.5,0), tck=-0.05, bty='l')
for(i in c(26,25,24,27,28,29)){
	plot(net.prop[,i] ~ net.prop[,23], pch=16, cex=0.6, col=rgb(0,0,0,0.3), asp=1, xlab='', ylab=gsub('stability2_', '', names(net.prop)[i]));abline(a=0, b=1, col='red')
}
for(i in c(26,25,24,27,28,29)){
	cor.vals$stab[i] <- unname(cor.test(net.prop[,i], net.prop[,23])$est)
}
cor.vals <- cor.vals[!is.na(cor.vals$stab),]












